@@ -311,11 +311,11 @@ def _perform_match(output, fnl):
 
 @pytest.fixture
 def cmd():
-    """ invoke a command line subcommand with a unique plugin manager. """
+    """invoke a command line subcommand with a unique plugin manager."""
     return CmdlineRunner()
 
 
 @pytest.fixture
-def mycmd(cmd, tmpdir, request):
+def mycmd(cmd, tmpdir):
     cmd.set_basedir(tmpdir.mkdir("account").strpath)
     return cmd
